@@ -14,6 +14,16 @@ from .utils import _get_function_name
 LOGGER = logging.getLogger(__name__)
 
 
+def _format_action(result: ResultMixin):
+    """
+    Returns a string representing the result's action (including name and action ID).
+    """
+    func_name = _get_function_name(result.action.name)
+    action_id = result.action_id
+
+    return f'{func_name} (action_id="{action_id}")'
+
+
 class AsyncResult:
     """Wrapper around the result object which performs
     updating and progress reporting."""
@@ -51,19 +61,21 @@ class AsyncResult:
         """Returns the current progress message."""
 
         status = self._result_object.action.status
-        func_name = _get_function_name(self._result_object.action.name)
+        action = _format_action(self._result_object)
 
         if status == self.PENDING:
             return (
-                f"Your task {func_name} is currently in "
-                "a queue waiting to be processed."
+                f"Your task {action} is currently in a queue waiting to be processed."
             )
 
         if status == self.STARTED:
-            return f"Your task {func_name} has started."
+            return (
+                f"Your task {action} has started. You can use the `qctrl.get_result` method to "
+                "retrieve previous results."
+            )
 
         if status == self.SUCCESS:
-            return f"Your task {func_name} has completed."
+            return f"Your task {action} has completed."
 
         return None
 
@@ -139,13 +151,10 @@ class AsyncResultCollection:
 
             if not async_result.result_object.is_successful:
 
-                identifier = (
-                    f"{async_result.result_object.name} "
-                    f"({async_result.result_object.action_id}): "
-                )
+                identifier = _format_action(async_result.result_object)
 
                 if async_result.result_object.job_errors:
-                    LOGGER.error(
+                    LOGGER.info(
                         "Action %s failed: %s",
                         async_result.result_object.action_id,
                         async_result.result_object.job_errors.exception,
@@ -153,7 +162,7 @@ class AsyncResultCollection:
                     exception = f"{async_result.result_object.job_errors.exception}"
 
                 elif async_result.result_object.status == "FAILURE":
-                    LOGGER.error(
+                    LOGGER.info(
                         "Action %s resulted with status 'FAILURE'("
                         "no extra details about the errors are "
                         "available).",
@@ -166,10 +175,11 @@ class AsyncResultCollection:
         if not failures:
             return
 
+        failure_message = "\n".join(": ".join(failure) for failure in failures)
+
         if len(self._async_results) == 1:
-            raise RuntimeError(failures[0][1])
+            raise RuntimeError(failure_message)
 
-        failure_message = "\n".join("".join(failure) for failure in failures)
         raise RuntimeError(
             f"Action failures: {len(failures)} of {len(self._async_results)}\n"
             f"{failure_message}"
