@@ -20,6 +20,7 @@ from typing import (
 )
 
 import requests
+from gql import Client
 from gql.transport.exceptions import (
     TransportClosed,
     TransportProtocolError,
@@ -37,7 +38,6 @@ from requests.compat import json as complexjson
 class QctrlRequestsHTTPTransport(RequestsHTTPTransport):
     """ Custom GQL requests class to enable compression of requests."""
 
-    # type: ignore
     def execute(  # pylint:disable=arguments-differ
         self,
         document: DocumentNode,
@@ -137,3 +137,16 @@ class QctrlRequestsHTTPTransport(RequestsHTTPTransport):
             raise TransportProtocolError("Server did not return a GraphQL result")
 
         return ExecutionResult(errors=result.get("errors"), data=result.get("data"))
+
+
+class QctrlGqlClient(Client):
+    """
+    Custom gql client class
+    """
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        # force the fetch schema for validating client and client version
+        with self as session:
+            session.fetch_schema()
