@@ -13,6 +13,7 @@
 # pylint:disable=missing-module-docstring
 import logging
 import os
+import sys
 from threading import Thread
 from typing import (
     Dict,
@@ -20,13 +21,13 @@ from typing import (
     Union,
 )
 
+import click
 import tenacity
 from gql import (
     Client,
     gql,
 )
 from qctrlcommons.exceptions import QctrlException
-from qctrlcommons.graph import Graph
 from requests.exceptions import (
     BaseHTTPError,
     RequestException,
@@ -38,13 +39,14 @@ from .builders import (
     create_client_auth,
     create_environment,
     create_gql_client,
-    validate_client_auth,
 )
 from .constants import DEFAULT_API_ROOT
+from .graphs import Graph
 from .parallel import ParallelExecutionCollector
 from .queries import (
     ActivityMonitorQuery,
     GetMutationNameQuery,
+    MeQuery,
 )
 from .utils import (
     _check_qctrl_latest_version,
@@ -94,10 +96,10 @@ class Qctrl:
 
     Attributes
     ----------
-    functions : qctrl.dynamic.namespaces.FunctionNamespace
-    operations : qctrl.dynamic.namespaces.OperationNamespace
-    types : qctrl.dynamic.namespaces.TypeNamespace
-
+    functions : :ref:`qctrl.dynamic.namespaces.FunctionNamespace`
+    types : :ref:`qctrl.dynamic.types`
+    operations
+        Deprecated, call methods on :py:obj:`~qctrl.graphs.Graph` instead.
 
     Raises
     ------
@@ -149,7 +151,17 @@ class Qctrl:
     @staticmethod
     def create_graph(name: str = None) -> Graph:
         """
-        Create a `Graph` object.
+        Creates a graph object for representing remote computations.
+
+        Parameters
+        ----------
+        name : deprecated
+            This parameter will be removed in the future.
+
+        Returns
+        -------
+        Graph
+            The new graph object.
         """
         return Graph(name=name)
 
@@ -215,12 +227,28 @@ class Qctrl:
         return result
 
     def parallel(self) -> ParallelExecutionCollector:
-        """Used for collecting multiple function calls to run in parallel.
+        """
+        Context manager for executing multiple function calls in parallel.
+
+        Any :ref:`functions <qctrl.dynamic.namespaces.FunctionNamespace>` that you call inside the
+        context manager will be scheduled for execution when the context manager exits. For
+        example:
+
+        .. code-block:: python
+
+          with qctrl.parallel():
+              result_1 = qctrl.functions.calculate_optimization(...)
+              result_2 = qctrl.functions.calculate_optimization(...)
+              # The functions get executed when the context manager exits, so result_1 and result_2
+              # do not have the results of the optimizations yet.
+
+          # Once outside the context manager, the functions have been executed, so result_1 and
+          # result_2 now contain the optimization results.
 
         Returns
         -------
         ParallelExecutionCollector
-            the collector object to be used as a context manager.
+            The context manager that collects function calls to be executed in parallel.
         """
         return ParallelExecutionCollector(self)
 
@@ -322,9 +350,32 @@ def _build_client(
     api_root = api_root or os.environ.get("QCTRL_API_HOST") or DEFAULT_API_ROOT
     assert api_root
 
-    auth = create_client_auth(api_root, email, password)
-    client = create_gql_client(api_root, auth)
-    validate_client_auth(client)
+    try:
+        auth = create_client_auth(api_root, email, password)
+        client = create_gql_client(api_root, auth)
+        MeQuery(client)()
+
+    except QctrlException as error:
+        LOGGER.info(error, exc_info=error)
+
+        if "token" in str(error):
+            description = """
+---------------------------------------------------------------------
+An error occurred with your session authentication. Please try again.
+If the issue persists, recreate your environment authentication by
+running `qctrl auth` from the command line.
+
+For non-interactive or alternative options check our help:
+
+    $ qctrl auth --help
+
+---------------------------------------------------------------------
+"""
+            click.echo(description, err=True)
+            sys.exit(1)
+
+        sys.exit(error)
+
     return client
 
 
