@@ -167,7 +167,7 @@ def _write_action_result_to_csv(path: str, actions: List):
     actions: List
         List of action data.
     """
-    with open(path, "w") as file:
+    with open(path, "w", encoding="utf-8") as file:
         writer = csv.DictWriter(file, fieldnames=actions[0].keys())
         writer.writeheader()
         for json_dict_result in actions:
